"""tizbrain: Placeholder package reservation for TizBrain."""

__all__ = ["hello", "__version__"]
__version__ = "0.0.1"

def hello() -> str:
    """Return a friendly placeholder string."""
    return "Hello tizbrain!"